@@ -22,12 +22,12 @@ import (
 	"testing"
 	"time"
 
+	"buf.build/go/standard/xlog/xslog"
 	"github.com/bufbuild/buf/private/buf/bufprotoc"
 	"github.com/bufbuild/buf/private/bufpkg/bufmodule"
 	"github.com/bufbuild/buf/private/pkg/github/githubtesting"
 	"github.com/bufbuild/buf/private/pkg/normalpath"
 	"github.com/bufbuild/buf/private/pkg/prototesting"
-	"github.com/bufbuild/buf/private/pkg/slogext"
 	"github.com/bufbuild/buf/private/pkg/storage/storageos"
 	"github.com/stretchr/testify/require"
 	"google.golang.org/protobuf/types/descriptorpb"
@@ -48,7 +48,7 @@ var (
 	}
 	testStorageosProvider = storageos.NewProvider(storageos.ProviderWithSymlinks())
 	testArchiveReader     = githubtesting.NewArchiveReader(
-		slogext.NopLogger,
+		xslog.NopLogger,
 		testStorageosProvider,
 		testHTTPClient,
 	)
@@ -130,7 +130,7 @@ func GetProtocFilePathsErr(ctx context.Context, dirPath string, limit int) ([]st
 	// impact on our dependency tree.
 	moduleSet, err := bufprotoc.NewModuleSetForProtoc(
 		ctx,
-		slogext.NopLogger,
+		xslog.NopLogger,
 		testStorageosProvider,
 		[]string{dirPath},
 		nil,
