@@ -1,4 +1,4 @@
-// Copyright 2020-2024 Buf Technologies, Inc.
+// Copyright 2020-2025 Buf Technologies, Inc.
 //
 // Licensed under the Apache License, Version 2.0 (the "License");
 // you may not use this file except in compliance with the License.
@@ -27,24 +27,23 @@ import (
 	"net/url"
 	"os"
 	"path/filepath"
-	"sort"
+	"slices"
 	"strings"
 	"sync"
 	"time"
 
+	"buf.build/go/app"
+	"buf.build/go/app/appcmd"
+	"buf.build/go/app/appext"
+	"buf.build/go/standard/xstrings"
 	"connectrpc.com/connect"
 	"github.com/bufbuild/buf/private/buf/bufcli"
 	"github.com/bufbuild/buf/private/buf/bufcurl"
-	"github.com/bufbuild/buf/private/pkg/app"
-	"github.com/bufbuild/buf/private/pkg/app/appcmd"
-	"github.com/bufbuild/buf/private/pkg/app/appext"
 	"github.com/bufbuild/buf/private/pkg/netrc"
-	"github.com/bufbuild/buf/private/pkg/stringutil"
 	"github.com/bufbuild/buf/private/pkg/verbose"
 	"github.com/quic-go/quic-go"
 	"github.com/quic-go/quic-go/http3"
 	"github.com/spf13/pflag"
-	"go.uber.org/multierr"
 	"golang.org/x/net/http2"
 	"google.golang.org/protobuf/reflect/protoreflect"
 )
@@ -607,7 +606,7 @@ func (f *flags) validate(hasURL, isSecure bool) error {
 			return fmt.Errorf(
 				"--%s value must be one of %s",
 				reflectProtocolFlagName,
-				stringutil.SliceToHumanStringOrQuoted(bufcurl.AllKnownReflectProtocolStrings),
+				xstrings.SliceToHumanStringOrQuoted(bufcurl.AllKnownReflectProtocolStrings),
 			)
 		}
 	}
@@ -952,7 +951,7 @@ func run(ctx context.Context, container appext.Container, f *flags) (err error)
 	}
 	defer func() {
 		if dataReader != nil {
-			err = multierr.Append(err, dataReader.Close())
+			err = errors.Join(err, dataReader.Close())
 		}
 	}()
 
@@ -1040,9 +1039,7 @@ func run(ctx context.Context, container appext.Container, f *flags) (err error)
 		if err != nil {
 			return err
 		}
-		sort.Slice(serviceNames, func(i, j int) bool {
-			return serviceNames[i] < serviceNames[j]
-		})
+		slices.Sort(serviceNames)
 		for _, serviceName := range serviceNames {
 			if f.ListServices {
 				if _, err := fmt.Fprintf(container.Stdout(), "%s\n", serviceName); err != nil {
@@ -1056,12 +1053,10 @@ func run(ctx context.Context, container appext.Container, f *flags) (err error)
 				methods := serviceDescriptor.Methods()
 				length := methods.Len()
 				methodNames := make([]protoreflect.Name, length)
-				for i := 0; i < length; i++ {
+				for i := range length {
 					methodNames[i] = methods.Get(i).Name()
 				}
-				sort.Slice(methodNames, func(i, j int) bool {
-					return methodNames[i] < methodNames[j]
-				})
+				slices.Sort(methodNames)
 				for _, methodName := range methodNames {
 					if _, err := fmt.Fprintf(container.Stdout(), "%s/%s\n", serviceName, methodName); err != nil {
 						return err
@@ -1185,7 +1180,7 @@ func makeHTTP3RoundTripper(f *flags, authority string, printer verbose.Printer)
 		return nil, err
 	}
 	transport := &quic.Transport{Conn: udpConn}
-	roundTripper := &http3.RoundTripper{
+	roundTripper := &http3.Transport{
 		TLSClientConfig: tlsConfig,
 		QUICConfig:      quicCfg,
 		Dial: func(ctx context.Context, addr string, tlsCfg *tls.Config, cfg *quic.Config) (quic.EarlyConnection, error) {
