@@ -1,4 +1,4 @@
-// Copyright 2020-2024 Buf Technologies, Inc.
+// Copyright 2020-2025 Buf Technologies, Inc.
 //
 // Licensed under the Apache License, Version 2.0 (the "License");
 // you may not use this file except in compliance with the License.
@@ -15,10 +15,10 @@
 package modlsbreakingrules
 
 import (
+	"buf.build/go/app/appcmd"
+	"buf.build/go/app/appext"
 	"buf.build/go/bufplugin/check"
 	"github.com/bufbuild/buf/private/buf/cmd/buf/command/mod/internal"
-	"github.com/bufbuild/buf/private/pkg/app/appcmd"
-	"github.com/bufbuild/buf/private/pkg/app/appext"
 )
 
 // NewCommand returns a new Command.
