@@ -982,8 +982,6 @@ func TestWorkspaceProtoFile(t *testing.T) {
 
 func TestWorkspaceBreakingFail(t *testing.T) {
 	t.Parallel()
-	// The two workspaces define a different number of
-	// images, so it's impossible to verify compatibility.
 	testRunStdout(
 		t,
 		nil,
@@ -992,6 +990,7 @@ func TestWorkspaceBreakingFail(t *testing.T) {
 		"build",
 		filepath.Join("testdata", "workspace", "fail", "breaking"),
 	)
+	// If the against contained more images than the input, we return a mismatch.
 	testRunStdoutStderrNoWarn(
 		t,
 		nil,
@@ -1014,6 +1013,53 @@ func TestWorkspaceBreakingFail(t *testing.T) {
 		"--against",
 		filepath.Join("testdata", "workspace", "success", "v2", "breaking"),
 	)
+	// If the input contains more images than the against, we attempt to map against images
+	// if there are no unique module-specific breaking configs for the input.
+	testRunStdout(
+		t,
+		nil,
+		bufctl.ExitCodeFileAnnotation,
+		filepath.FromSlash(
+			`testdata/workspace/success/dir/other/proto/request.proto:6:3:Field "1" with name "name" on message "Request" changed type from "int64" to "string".`,
+		),
+		"breaking",
+		filepath.Join("testdata", "workspace", "success", "dir"),
+		"--against",
+		filepath.Join("testdata", "workspace", "fail", "breaking"),
+	)
+	testRunStdout(
+		t,
+		nil,
+		bufctl.ExitCodeFileAnnotation,
+		filepath.FromSlash(
+			`testdata/workspace/success/v2/dir/other/proto/request.proto:6:3:Field "1" with name "name" on message "Request" changed type from "int64" to "string".`,
+		),
+		"breaking",
+		filepath.Join("testdata", "workspace", "success", "v2", "dir"),
+		"--against",
+		filepath.Join("testdata", "workspace", "fail", "breaking"),
+	)
+	// If we find unique module-specific breaking changes, then we still fail with a mismatch error.
+	testRunStdout(
+		t,
+		nil,
+		1,
+		``,
+		"breaking",
+		filepath.Join("testdata", "workspace", "fail", "modulebreakingconfig"),
+		"--against",
+		filepath.Join("testdata", "workspace", "fail", "breaking"),
+	)
+	testRunStdout(
+		t,
+		nil,
+		1,
+		``,
+		"breaking",
+		filepath.Join("testdata", "workspace", "fail", "v2", "modulebreakingconfig"),
+		"--against",
+		filepath.Join("testdata", "workspace", "fail", "breaking"),
+	)
 }
 
 func TestWorkspaceDuplicateDirPathSuccess(t *testing.T) {
@@ -1269,7 +1315,6 @@ func TestWorkspaceJumpContextFail(t *testing.T) {
 		nil,
 		1,
 		``,
-		// TODO FUTURE: figure out why even on windows, the cleaned, unnormalised path is "/"-separated from decode error
 		`Failure: decode testdata/workspace/fail/jumpcontext/buf.work.yaml: directory "../breaking/other/proto" is invalid: ../breaking/other/proto: is outside the context directory`,
 		"build",
 		filepath.Join("testdata", "workspace", "fail", "jumpcontext"),
@@ -1279,7 +1324,6 @@ func TestWorkspaceJumpContextFail(t *testing.T) {
 		nil,
 		1,
 		``,
-		// TODO FUTURE: figure out why even on windows, the cleaned, unnormalised path is "/"-separated from decode error
 		`Failure: decode testdata/workspace/fail/v2/jumpcontext/buf.yaml: invalid module path: ../breaking/other/proto: is outside the context directory`,
 		"build",
 		filepath.Join("testdata", "workspace", "fail", "v2", "jumpcontext"),
@@ -1294,7 +1338,6 @@ func TestWorkspaceDirOverlapFail(t *testing.T) {
 		nil,
 		1,
 		``,
-		// TODO FUTURE: figure out why even on windows, the cleaned, unnormalised path is "/"-separated from decode error
 		`Failure: decode testdata/workspace/fail/diroverlap/buf.work.yaml: directory "foo" contains directory "foo/bar"`,
 		"build",
 		filepath.Join("testdata", "workspace", "fail", "diroverlap"),
@@ -1350,7 +1393,6 @@ func TestWorkspaceNoVersionFail(t *testing.T) {
 		nil,
 		1,
 		``,
-		// TODO FUTURE: figure out why even on windows, the cleaned, unnormalised path is "/"-separated from decode error
 		`Failure: decode testdata/workspace/fail/noversion/buf.work.yaml: "version" is not set. Please add "version: v1"`,
 		"build",
 		filepath.Join("testdata", "workspace", "fail", "noversion"),
@@ -1365,7 +1407,6 @@ func TestWorkspaceInvalidVersionFail(t *testing.T) {
 		nil,
 		1,
 		``,
-		// TODO FUTURE: figure out why even on windows, the cleaned, unnormalised path is "/"-separated from decode error
 		`Failure: decode testdata/workspace/fail/invalidversion/buf.work.yaml: unknown file version: "v9"`,
 		"build",
 		filepath.Join("testdata", "workspace", "fail", "invalidversion"),
@@ -1380,7 +1421,6 @@ func TestWorkspaceNoDirectoriesFail(t *testing.T) {
 		nil,
 		1,
 		``,
-		// TODO FUTURE: figure out why even on windows, the cleaned, unnormalised path is "/"-separated from decode error
 		`Failure: decode testdata/workspace/fail/nodirectories/buf.work.yaml: directories is empty`,
 		"build",
 		filepath.Join("testdata", "workspace", "fail", "nodirectories"),
