@@ -28,11 +28,9 @@ import (
 	"github.com/bufbuild/buf/private/bufpkg/bufanalysis"
 	"github.com/bufbuild/buf/private/bufpkg/bufcheck"
 	"github.com/bufbuild/buf/private/bufpkg/bufimage"
-	"github.com/bufbuild/buf/private/bufpkg/bufplugin"
 	"github.com/bufbuild/buf/private/pkg/encoding"
 	"github.com/bufbuild/buf/private/pkg/protodescriptor"
 	"github.com/bufbuild/buf/private/pkg/protoencoding"
-	"github.com/bufbuild/buf/private/pkg/wasm"
 	"github.com/bufbuild/protoplugin"
 )
 
@@ -58,7 +56,7 @@ func handle(
 	pluginEnv protoplugin.PluginEnv,
 	responseWriter protoplugin.ResponseWriter,
 	request protoplugin.Request,
-) error {
+) (retErr error) {
 	responseWriter.SetFeatureProto3Optional()
 	responseWriter.SetFeatureSupportsEditions(protodescriptor.MinSupportedEdition, protodescriptor.MaxSupportedEdition)
 	externalConfig := &externalConfig{}
@@ -123,15 +121,21 @@ func handle(
 	if err != nil {
 		return err
 	}
-	// The protoc plugins do not support custom lint/breaking change plugins for now.
+	// The protoc plugins only support local plugins.
+	wasmRuntime, err := bufcli.NewWasmRuntime(ctx, container)
+	if err != nil {
+		return err
+	}
+	defer func() {
+		retErr = errors.Join(retErr, wasmRuntime.Close(ctx))
+	}()
 	client, err := bufcheck.NewClient(
 		container.Logger(),
-		bufcheck.NewLocalRunnerProvider(
-			wasm.UnimplementedRuntime,
-			bufplugin.NopPluginKeyProvider,
-			bufplugin.NopPluginDataProvider,
-		),
 		bufcheck.ClientWithStderr(pluginEnv.Stderr),
+		bufcheck.ClientWithRunnerProvider(
+			bufcheck.NewLocalRunnerProvider(wasmRuntime),
+		),
+		bufcheck.ClientWithLocalWasmPluginsFromOS(),
 	)
 	if err != nil {
 		return err
