@@ -1,4 +1,4 @@
-// Copyright 2020-2024 Buf Technologies, Inc.
+// Copyright 2020-2025 Buf Technologies, Inc.
 //
 // Licensed under the Apache License, Version 2.0 (the "License");
 // you may not use this file except in compliance with the License.
@@ -17,7 +17,7 @@ package bufconfig
 import (
 	"testing"
 
-	"github.com/bufbuild/buf/private/pkg/slicesext"
+	"buf.build/go/standard/xslices"
 	"github.com/stretchr/testify/require"
 	"google.golang.org/protobuf/proto"
 	"google.golang.org/protobuf/types/descriptorpb"
@@ -91,8 +91,8 @@ func TestParseConfigFromExternalV1(t *testing.T) {
 					{
 						Name:     "go",
 						Out:      "go/out",
-						Path:     slicesext.Map([]string{"go", "run", "goplugin"}, func(s string) interface{} { return s }),
-						Opt:      slicesext.Map([]string{"a=b", "c"}, func(s string) interface{} { return s }),
+						Path:     xslices.Map([]string{"go", "run", "goplugin"}, func(s string) any { return s }),
+						Opt:      xslices.Map([]string{"a=b", "c"}, func(s string) any { return s }),
 						Strategy: "directory",
 					},
 				},
@@ -119,8 +119,8 @@ func TestParseConfigFromExternalV1(t *testing.T) {
 					{
 						Plugin:   "go",
 						Out:      "go/out",
-						Path:     slicesext.Map([]string{"go", "run", "goplugin"}, func(s string) interface{} { return s }),
-						Opt:      slicesext.Map([]string{"a=b", "c"}, func(s string) interface{} { return s }),
+						Path:     xslices.Map([]string{"go", "run", "goplugin"}, func(s string) any { return s }),
+						Opt:      xslices.Map([]string{"a=b", "c"}, func(s string) any { return s }),
 						Strategy: "directory",
 					},
 				},
@@ -688,7 +688,6 @@ func TestParseConfigFromExternalV1(t *testing.T) {
 		},
 	}
 	for _, testcase := range testcases {
-		testcase := testcase
 		t.Run(testcase.description, func(t *testing.T) {
 			t.Parallel()
 			parsedConfig, err := newGenerateConfigFromExternalFileV1(testcase.externalConfig)
@@ -764,7 +763,6 @@ func TestParseConfigFromExternalV1Fail(t *testing.T) {
 		},
 	}
 	for _, testcase := range testcases {
-		testcase := testcase
 		t.Run(testcase.description, func(t *testing.T) {
 			t.Parallel()
 			_, err := newGenerateConfigFromExternalFileV1(testcase.externalConfig)
