@@ -15,7 +15,6 @@
 // Matching the unix-like build tags in the Golang source i.e. https://github.com/golang/go/blob/912f0750472dd4f674b69ca1616bfaf377af1805/src/os/file_unix.go#L6
 
 //go:build aix || darwin || dragonfly || freebsd || (js && wasm) || linux || netbsd || openbsd || solaris
-// +build aix darwin dragonfly freebsd js,wasm linux netbsd openbsd solaris
 
 package netrc
 
@@ -27,7 +26,7 @@ import (
 	"strings"
 	"testing"
 
-	"github.com/bufbuild/buf/private/pkg/app"
+	"buf.build/go/app"
 	"github.com/stretchr/testify/assert"
 	"github.com/stretchr/testify/require"
 )
@@ -136,9 +135,9 @@ func TestPutLotsOfBigMachinesSingleLineFiles(t *testing.T) {
 	password := strings.Repeat("abcdefghijklmnopqrstuvwxyz", size)
 	machines := make([]Machine, 0, size)
 	buffer := bytes.NewBuffer(nil)
-	for i := 0; i < size; i++ {
+	for i := range size {
 		// Write the file manually in single-line format as this is where the failure happens.
-		_, _ = buffer.WriteString(fmt.Sprintf("machine foo%d login bar%d password %s\n", i, i, password))
+		fmt.Fprintf(buffer, "machine foo%d login bar%d password %s\n", i, i, password)
 		machines = append(
 			machines,
 			NewMachine(
@@ -178,7 +177,7 @@ func TestPutLotsOfBigMachinesSingleLineFiles(t *testing.T) {
 
 	// Modify some of the existing machines.
 	machines = make([]Machine, 0, size)
-	for i := 0; i < size; i++ {
+	for i := range size {
 		modifiedPassword := password
 		if i%2 == 0 {
 			modifiedPassword = modifiedPassword + "Z"
