@@ -1,4 +1,4 @@
-// Copyright 2020-2024 Buf Technologies, Inc.
+// Copyright 2020-2025 Buf Technologies, Inc.
 //
 // Licensed under the Apache License, Version 2.0 (the "License");
 // you may not use this file except in compliance with the License.
@@ -28,10 +28,10 @@ import (
 	"sort"
 	"strconv"
 	"sync"
+	"sync/atomic"
 	"testing"
 
-	"github.com/bufbuild/buf/private/pkg/command"
-	"github.com/bufbuild/buf/private/pkg/slicesext"
+	"buf.build/go/standard/xslices"
 	"github.com/bufbuild/buf/private/pkg/storage"
 	"github.com/bufbuild/buf/private/pkg/storage/storagearchive"
 	"github.com/bufbuild/buf/private/pkg/storage/storageos"
@@ -39,7 +39,6 @@ import (
 	"github.com/bufbuild/buf/private/pkg/tmp"
 	"github.com/stretchr/testify/assert"
 	"github.com/stretchr/testify/require"
-	"go.uber.org/atomic"
 )
 
 const (
@@ -117,7 +116,7 @@ func AssertPathToContent(
 			return nil
 		},
 	))
-	require.Equal(t, len(paths), len(slicesext.ToUniqueSorted(paths)))
+	require.Equal(t, len(paths), len(xslices.ToUniqueSorted(paths)))
 	assert.Equal(t, len(expectedPathToContent), len(paths), paths)
 	for _, path := range paths {
 		expectedContent, ok := expectedPathToContent[path]
@@ -150,7 +149,7 @@ func AssertPaths(
 		},
 	))
 	sort.Strings(paths)
-	assert.Equal(t, slicesext.ToUniqueSorted(expectedPaths), paths)
+	assert.Equal(t, xslices.ToUniqueSorted(expectedPaths), paths)
 }
 
 // GetExternalPathFunc can be used to get the external path of
@@ -178,14 +177,12 @@ func RunTestSuite(
 	symlinkLoopDirPath := filepath.Join(storagetestingDirPath, "testdata", "symlink_loop")
 	overlayDirPath := filepath.Join(storagetestingDirPath, "testdata", "overlay")
 	defaultProvider := storageos.NewProvider()
-	runner := command.NewRunner()
 
 	for _, prefix := range []string{
 		"",
 		".",
 		"./",
 	} {
-		prefix := prefix
 		t.Run(fmt.Sprintf("root-%q", prefix), func(t *testing.T) {
 			t.Parallel()
 			readBucket, _ := newReadBucket(t, oneDirPath, defaultProvider)
@@ -907,7 +904,6 @@ func RunTestSuite(
 			},
 		},
 	} {
-		testCase := testCase
 		if testCase.stripComponentCount == 0 {
 			t.Run(fmt.Sprintf("copy-%s", testCase.name), func(t *testing.T) {
 				t.Parallel()
@@ -1042,7 +1038,6 @@ func RunTestSuite(
 
 		diff, err := storage.DiffBytes(
 			context.Background(),
-			runner,
 			readBucketA,
 			readBucketB,
 			storage.DiffWithSuppressTimestamps(),
@@ -1480,7 +1475,7 @@ func RunTestSuite(
 			writtenBytes atomic.Int64
 			triedBytes   atomic.Int64
 		)
-		for i := 0; i < 10; i++ {
+		for i := range 10 {
 			wg.Add(1)
 			go func(i int) {
 				defer wg.Done()
